@@ -4,9 +4,26 @@ use Test::Class::Most parent => 'TestHelper::Test::Class';
 use strict;
 use warnings;
 
+use Module::Runtime qw( require_module );
+use Try::Tiny;
+
+BEGIN {
+    for my $mod (qw( Parallel::ForkManager )) {
+        unless ( try { require_module($mod); 1 } ) {
+            __PACKAGE__->SKIP_CLASS("This test requires the $mod module");
+            return;
+        }
+    }
+}
+
 sub test_parallel : Tests {
     my $self = shift;
 
+    if ( $^O eq 'MSWin32' ) {
+        $self->builder->skip('Parallel::ForkManager does not seem to work on Windows');
+        return;
+    }
+
     $self->tidy(
         plugins => {
             '+TestHelper::Plugin::UpperText' => {
