@@ -1,11 +1,13 @@
 package TestFor::Code::TidyAll::Plugin::GenericValidator;
 
 use Test::Class::Most parent => 'TestFor::Code::TidyAll::Plugin';
+use FindBin qw( $Bin );
+use Path::Tiny qw( path );
 
 sub test_main : Tests {
     my $self = shift;
 
-    my $cmd = $self->_this_perl . ' t/helper-bin/generic-validator.pl';
+    my $cmd = join q{ }, $self->_this_perl, path( $Bin, qw( helper-bin generic-validator.pl ) );
 
     $self->tidyall(
         source    => 'this text is ok',
@@ -16,15 +18,15 @@ sub test_main : Tests {
         },
     );
     $self->tidyall(
-        source    => 'this text is forbidden',
-        expect_ok => 0,
-        desc      => 'text does contain forbidden word',
-        conf      => {
+        source       => 'this text is forbidden',
+        expect_error => qr/exited with 1/,
+        desc         => 'text does contain forbidden word',
+        conf         => {
             cmd => $cmd,
         },
     );
 
-    my $exit = $self->_this_perl . ' t/helper-bin/exit.pl';
+    my $exit = join q{ }, $self->_this_perl, path( $Bin, qw( helper-bin exit.pl ) );
     $self->tidyall(
         source    => 'this text is fine',
         expect_ok => 1,
