@@ -5,7 +5,7 @@ extends 'Code::TidyAll::Plugin';
 
 sub transform_source {
     my ( $self, $source ) = @_;
-    if ( $source =~ /^[A-Z]*$/i ) {
+    if ( $source =~ /^[A-Z]*$/mi ) {
         return uc($source);
     }
     else {
